summaryrefslogtreecommitdiffstats
path: root/ui
diff options
context:
space:
mode:
Diffstat (limited to 'ui')
-rw-r--r--ui/base/cursor/cursor.h2
-rw-r--r--ui/base/cursor/cursors_aura.cc53
-rw-r--r--ui/resources/default_100_percent/common/pointers/alias_big.pngbin0 -> 2358 bytes
-rw-r--r--ui/resources/default_100_percent/common/pointers/cell_big.pngbin0 -> 509 bytes
-rw-r--r--ui/resources/default_100_percent/common/pointers/context_menu_big.pngbin0 -> 1325 bytes
-rw-r--r--ui/resources/default_100_percent/common/pointers/copy_big.pngbin0 -> 2414 bytes
-rw-r--r--ui/resources/default_100_percent/common/pointers/crosshair_big.pngbin0 -> 164 bytes
-rw-r--r--ui/resources/default_100_percent/common/pointers/fleur_big.pngbin0 -> 1765 bytes
-rw-r--r--ui/resources/default_100_percent/common/pointers/hand2_big.pngbin0 -> 1387 bytes
-rw-r--r--ui/resources/default_100_percent/common/pointers/hand3_big.pngbin0 -> 1401 bytes
-rw-r--r--ui/resources/default_100_percent/common/pointers/help_big.pngbin0 -> 1768 bytes
-rw-r--r--ui/resources/default_100_percent/common/pointers/left_ptr_big.pngbin0 -> 1084 bytes
-rw-r--r--ui/resources/default_100_percent/common/pointers/move_big.pngbin0 -> 1166 bytes
-rw-r--r--ui/resources/default_100_percent/common/pointers/nodrop_big.pngbin0 -> 2636 bytes
-rw-r--r--ui/resources/default_100_percent/common/pointers/sb_h_double_arrow_big.pngbin0 -> 828 bytes
-rw-r--r--ui/resources/default_100_percent/common/pointers/sb_v_double_arrow_big.pngbin0 -> 801 bytes
-rw-r--r--ui/resources/default_100_percent/common/pointers/top_left_corner_big.pngbin0 -> 1000 bytes
-rw-r--r--ui/resources/default_100_percent/common/pointers/top_right_corner_big.pngbin0 -> 991 bytes
-rw-r--r--ui/resources/default_100_percent/common/pointers/xterm_big.pngbin0 -> 488 bytes
-rw-r--r--ui/resources/default_100_percent/common/pointers/xterm_horiz_big.pngbin0 -> 495 bytes
-rw-r--r--ui/resources/default_100_percent/common/pointers/zoom_in_big.pngbin0 -> 2287 bytes
-rw-r--r--ui/resources/default_100_percent/common/pointers/zoom_out_big.pngbin0 -> 2243 bytes
-rw-r--r--ui/resources/ui_resources.grd31
23 files changed, 83 insertions, 3 deletions
diff --git a/ui/base/cursor/cursor.h b/ui/base/cursor/cursor.h
index 40cfb2e..bb832fa 100644
--- a/ui/base/cursor/cursor.h
+++ b/ui/base/cursor/cursor.h
@@ -84,8 +84,6 @@ const int kCursorCustom = 44;
enum CursorSetType {
CURSOR_SET_NORMAL,
- // Don't use this large cursor set now, except in tests. Large assets are not
- // added yet. crbug.com/247254
CURSOR_SET_LARGE
};
diff --git a/ui/resources/default_100_percent/common/pointers/alias_big.png b/ui/resources/default_100_percent/common/pointers/alias_big.png
new file mode 100644
index 0000000..283bf7f
--- /dev/null
+++ b/ui/resources/default_100_percent/common/pointers/alias_big.png
Binary files differ
diff --git a/ui/resources/default_100_percent/common/pointers/cell_big.png b/ui/resources/default_100_percent/common/pointers/cell_big.png
new file mode 100644
index 0000000..3dec5e5
--- /dev/null
+++ b/ui/resources/default_100_percent/common/pointers/cell_big.png
Binary files differ
diff --git a/ui/resources/default_100_percent/common/pointers/context_menu_big.png b/ui/resources/default_100_percent/common/pointers/context_menu_big.png
new file mode 100644
index 0000000..7c9e250
--- /dev/null
+++ b/ui/resources/default_100_percent/common/pointers/context_menu_big.png
Binary files differ
diff --git a/ui/resources/default_100_percent/common/pointers/copy_big.png b/ui/resources/default_100_percent/common/pointers/copy_big.png
new file mode 100644
index 0000000..3e38e45
--- /dev/null
+++ b/ui/resources/default_100_percent/common/pointers/copy_big.png
Binary files differ
diff --git a/ui/resources/default_100_percent/common/pointers/crosshair_big.png b/ui/resources/default_100_percent/common/pointers/crosshair_big.png
new file mode 100644
index 0000000..ea1f5fc
--- /dev/null
+++ b/ui/resources/default_100_percent/common/pointers/crosshair_big.png
Binary files differ
diff --git a/ui/resources/default_100_percent/common/pointers/fleur_big.png b/ui/resources/default_100_percent/common/pointers/fleur_big.png
new file mode 100644
index 0000000..2e32766
--- /dev/null
+++ b/ui/resources/default_100_percent/common/pointers/fleur_big.png
Binary files differ
diff --git a/ui/resources/default_100_percent/common/pointers/hand2_big.png b/ui/resources/default_100_percent/common/pointers/hand2_big.png
new file mode 100644
index 0000000..63bb959
--- /dev/null
+++ b/ui/resources/default_100_percent/common/pointers/hand2_big.png
Binary files differ
diff --git a/ui/resources/default_100_percent/common/pointers/hand3_big.png b/ui/resources/default_100_percent/common/pointers/hand3_big.png
new file mode 100644
index 0000000..3c54751
--- /dev/null
+++ b/ui/resources/default_100_percent/common/pointers/hand3_big.png
Binary files differ
diff --git a/ui/resources/default_100_percent/common/pointers/help_big.png b/ui/resources/default_100_percent/common/pointers/help_big.png
new file mode 100644
index 0000000..6552f9b
--- /dev/null
+++ b/ui/resources/default_100_percent/common/pointers/help_big.png
Binary files differ
diff --git a/ui/resources/default_100_percent/common/pointers/left_ptr_big.png b/ui/resources/default_100_percent/common/pointers/left_ptr_big.png
new file mode 100644
index 0000000..c5604c7
--- /dev/null
+++ b/ui/resources/default_100_percent/common/pointers/left_ptr_big.png
Binary files differ
diff --git a/ui/resources/default_100_percent/common/pointers/move_big.png b/ui/resources/default_100_percent/common/pointers/move_big.png
new file mode 100644
index 0000000..c29db87
--- /dev/null
+++ b/ui/resources/default_100_percent/common/pointers/move_big.png
Binary files differ
diff --git a/ui/resources/default_100_percent/common/pointers/nodrop_big.png b/ui/resources/default_100_percent/common/pointers/nodrop_big.png
new file mode 100644
index 0000000..da981df3
--- /dev/null
+++ b/ui/resources/default_100_percent/common/pointers/nodrop_big.png
Binary files differ
diff --git a/ui/resources/default_100_percent/common/pointers/sb_h_double_arrow_big.png b/ui/resources/default_100_percent/common/pointers/sb_h_double_arrow_big.png
new file mode 100644
index 0000000..49dc3d3
--- /dev/null
+++ b/ui/resources/default_100_percent/common/pointers/sb_h_double_arrow_big.png
Binary files differ
diff --git a/ui/resources/default_100_percent/common/pointers/sb_v_double_arrow_big.png b/ui/resources/default_100_percent/common/pointers/sb_v_double_arrow_big.png
new file mode 100644
index 0000000..7b2135d2
--- /dev/null
+++ b/ui/resources/default_100_percent/common/pointers/sb_v_double_arrow_big.png
Binary files differ
diff --git a/ui/resources/default_100_percent/common/pointers/top_left_corner_big.png b/ui/resources/default_100_percent/common/pointers/top_left_corner_big.png
new file mode 100644
index 0000000..eecaa89
--- /dev/null
+++ b/ui/resources/default_100_percent/common/pointers/top_left_corner_big.png
Binary files differ
diff --git a/ui/resources/default_100_percent/common/pointers/top_right_corner_big.png b/ui/resources/default_100_percent/common/pointers/top_right_corner_big.png
new file mode 100644
index 0000000..9d47ecf
--- /dev/null
+++ b/ui/resources/default_100_percent/common/pointers/top_right_corner_big.png
Binary files differ
diff --git a/ui/resources/default_100_percent/common/pointers/xterm_big.png b/ui/resources/default_100_percent/common/pointers/xterm_big.png
new file mode 100644
index 0000000..2fba190
--- /dev/null
+++ b/ui/resources/default_100_percent/common/pointers/xterm_big.png
Binary files differ
diff --git a/ui/resources/default_100_percent/common/pointers/xterm_horiz_big.png b/ui/resources/default_100_percent/common/pointers/xterm_horiz_big.png
new file mode 100644
index 0000000..94f5ddc
--- /dev/null
+++ b/ui/resources/default_100_percent/common/pointers/xterm_horiz_big.png
Binary files differ
diff --git a/ui/resources/default_100_percent/common/pointers/zoom_in_big.png b/ui/resources/default_100_percent/common/pointers/zoom_in_big.png
new file mode 100644
index 0000000..923ad79
--- /dev/null
+++ b/ui/resources/default_100_percent/common/pointers/zoom_in_big.png
Binary files differ
diff --git a/ui/resources/default_100_percent/common/pointers/zoom_out_big.png b/ui/resources/default_100_percent/common/pointers/zoom_out_big.png
new file mode 100644
index 0000000..aa47eb9
--- /dev/null
+++ b/ui/resources/default_100_percent/common/pointers/zoom_out_big.png
Binary files differ
diff --git a/ui/resources/ui_resources.grd b/ui/resources/ui_resources.grd
index 2cb91be..dd510db 100644
--- a/ui/resources/ui_resources.grd
+++ b/ui/resources/ui_resources.grd
@@ -36,6 +36,37 @@
<structure type="chrome_scaled_image" name="IDR_APP_TOP_RIGHT" file="app_top_right.png" />
</if>
<if expr="is_linux and pp_ifdef('use_aura')">
+ <structure type="chrome_scaled_image" name="IDR_AURA_CURSOR_BIG_ALIAS" file="common/pointers/alias_big.png" />
+ <structure type="chrome_scaled_image" name="IDR_AURA_CURSOR_BIG_CELL" file="common/pointers/cell_big.png" />
+ <structure type="chrome_scaled_image" name="IDR_AURA_CURSOR_BIG_COL_RESIZE" file="common/pointers/sb_h_double_arrow_big.png" />
+ <structure type="chrome_scaled_image" name="IDR_AURA_CURSOR_BIG_CONTEXT_MENU" file="common/pointers/context_menu_big.png" />
+ <structure type="chrome_scaled_image" name="IDR_AURA_CURSOR_BIG_COPY" file="common/pointers/copy_big.png" />
+ <structure type="chrome_scaled_image" name="IDR_AURA_CURSOR_BIG_CROSSHAIR" file="common/pointers/crosshair_big.png" />
+ <structure type="chrome_scaled_image" name="IDR_AURA_CURSOR_BIG_EAST_RESIZE" file="common/pointers/sb_h_double_arrow_big.png" />
+ <structure type="chrome_scaled_image" name="IDR_AURA_CURSOR_BIG_EAST_WEST_RESIZE" file="common/pointers/sb_h_double_arrow_big.png" />
+ <structure type="chrome_scaled_image" name="IDR_AURA_CURSOR_BIG_FLEUR" file="common/pointers/fleur_big.png" />
+ <structure type="chrome_scaled_image" name="IDR_AURA_CURSOR_BIG_HAND" file="common/pointers/hand2_big.png" />
+ <structure type="chrome_scaled_image" name="IDR_AURA_CURSOR_BIG_HELP" file="common/pointers/help_big.png" />
+ <structure type="chrome_scaled_image" name="IDR_AURA_CURSOR_BIG_IBEAM" file="common/pointers/xterm_big.png" />
+ <structure type="chrome_scaled_image" name="IDR_AURA_CURSOR_BIG_MOVE" file="common/pointers/move_big.png" />
+ <structure type="chrome_scaled_image" name="IDR_AURA_CURSOR_BIG_NORTH_EAST_RESIZE" file="common/pointers/top_right_corner_big.png" />
+ <structure type="chrome_scaled_image" name="IDR_AURA_CURSOR_BIG_NORTH_EAST_SOUTH_WEST_RESIZE" file="common/pointers/top_right_corner_big.png" />
+ <structure type="chrome_scaled_image" name="IDR_AURA_CURSOR_BIG_NORTH_RESIZE" file="common/pointers/sb_v_double_arrow_big.png" />
+ <structure type="chrome_scaled_image" name="IDR_AURA_CURSOR_BIG_NORTH_SOUTH_RESIZE" file="common/pointers/sb_v_double_arrow_big.png" />
+ <structure type="chrome_scaled_image" name="IDR_AURA_CURSOR_BIG_NORTH_WEST_RESIZE" file="common/pointers/top_left_corner_big.png" />
+ <structure type="chrome_scaled_image" name="IDR_AURA_CURSOR_BIG_NORTH_WEST_SOUTH_EAST_RESIZE" file="common/pointers/top_left_corner_big.png" />
+ <structure type="chrome_scaled_image" name="IDR_AURA_CURSOR_BIG_NO_DROP" file="common/pointers/nodrop_big.png" />
+ <structure type="chrome_scaled_image" name="IDR_AURA_CURSOR_BIG_PTR" file="common/pointers/left_ptr_big.png" />
+ <structure type="chrome_scaled_image" name="IDR_AURA_CURSOR_BIG_ROW_RESIZE" file="common/pointers/sb_v_double_arrow_big.png" />
+ <structure type="chrome_scaled_image" name="IDR_AURA_CURSOR_BIG_SOUTH_EAST_RESIZE" file="common/pointers/top_left_corner_big.png" />
+ <structure type="chrome_scaled_image" name="IDR_AURA_CURSOR_BIG_SOUTH_RESIZE" file="common/pointers/sb_v_double_arrow_big.png" />
+ <structure type="chrome_scaled_image" name="IDR_AURA_CURSOR_BIG_SOUTH_WEST_RESIZE" file="common/pointers/top_right_corner_big.png" />
+ <structure type="chrome_scaled_image" name="IDR_AURA_CURSOR_BIG_WEST_RESIZE" file="common/pointers/sb_h_double_arrow_big.png" />
+ <structure type="chrome_scaled_image" name="IDR_AURA_CURSOR_BIG_XTERM_HORIZ" file="common/pointers/xterm_horiz_big.png" />
+ <structure type="chrome_scaled_image" name="IDR_AURA_CURSOR_BIG_ZOOM_IN" file="common/pointers/zoom_in_big.png" />
+ <structure type="chrome_scaled_image" name="IDR_AURA_CURSOR_BIG_ZOOM_OUT" file="common/pointers/zoom_out_big.png" />
+ <structure type="chrome_scaled_image" name="IDR_AURA_CURSOR_BIG_GRAB" file="common/pointers/fleur_big.png" />
+ <structure type="chrome_scaled_image" name="IDR_AURA_CURSOR_BIG_GRABBING" file="common/pointers/hand3_big.png" />
<structure type="chrome_scaled_image" name="IDR_AURA_CURSOR_ALIAS" file="common/pointers/alias.png" />
<structure type="chrome_scaled_image" name="IDR_AURA_CURSOR_CELL" file="common/pointers/cell.png" />
<structure type="chrome_scaled_image" name="IDR_AURA_CURSOR_COL_RESIZE" file="common/pointers/sb_h_double_arrow.png" />
diff --git a/ui/base/cursor/cursors_aura.cc b/ui/base/cursor/cursors_aura.cc
index d27a7b7..bb5947a 100644
--- a/ui/base/cursor/cursors_aura.cc
+++ b/ui/base/cursor/cursors_aura.cc
@@ -74,6 +74,52 @@ const CursorData kNormalCursors[] = {
{ui::kCursorGrabbing, IDR_AURA_CURSOR_GRABBING, {9, 9}, {18, 18}},
};
+const CursorData kLargeCursors[] = {
+ {ui::kCursorNull, IDR_AURA_CURSOR_BIG_PTR, {10, 10}, {10, 10}},
+ {ui::kCursorPointer, IDR_AURA_CURSOR_BIG_PTR, {10, 10}, {10, 10}},
+ {ui::kCursorNoDrop, IDR_AURA_CURSOR_BIG_NO_DROP, {23, 23}, {23, 23}},
+ {ui::kCursorNotAllowed, IDR_AURA_CURSOR_BIG_NO_DROP, {23, 23}, {23, 23}},
+ {ui::kCursorCopy, IDR_AURA_CURSOR_BIG_COPY, {23, 23}, {23, 23}},
+ {ui::kCursorHand, IDR_AURA_CURSOR_BIG_HAND, {23, 10}, {23, 10}},
+ {ui::kCursorMove, IDR_AURA_CURSOR_BIG_MOVE, {28, 28}, {28, 28}},
+ {ui::kCursorNorthEastResize, IDR_AURA_CURSOR_BIG_NORTH_EAST_RESIZE,
+ {31, 28}, {31, 28}},
+ {ui::kCursorSouthWestResize, IDR_AURA_CURSOR_BIG_SOUTH_WEST_RESIZE,
+ {31, 28}, {31, 28}},
+ {ui::kCursorSouthEastResize, IDR_AURA_CURSOR_BIG_SOUTH_EAST_RESIZE,
+ {28, 28}, {28, 28}},
+ {ui::kCursorNorthWestResize, IDR_AURA_CURSOR_BIG_NORTH_WEST_RESIZE,
+ {28, 28}, {28, 28}},
+ {ui::kCursorNorthResize, IDR_AURA_CURSOR_BIG_NORTH_RESIZE,
+ {28, 31}, {28, 31}},
+ {ui::kCursorSouthResize, IDR_AURA_CURSOR_BIG_SOUTH_RESIZE,
+ {28, 31}, {28, 31}},
+ {ui::kCursorEastResize, IDR_AURA_CURSOR_BIG_EAST_RESIZE, {31, 28}, {31, 28}},
+ {ui::kCursorWestResize, IDR_AURA_CURSOR_BIG_WEST_RESIZE, {31, 28}, {31, 28}},
+ {ui::kCursorIBeam, IDR_AURA_CURSOR_BIG_IBEAM, {31, 31}, {31, 31}},
+ {ui::kCursorAlias, IDR_AURA_CURSOR_BIG_ALIAS, {51, 15}, {51, 11}},
+ {ui::kCursorCell, IDR_AURA_CURSOR_BIG_CELL, {28, 28}, {24, 23}},
+ {ui::kCursorContextMenu, IDR_AURA_CURSOR_BIG_CONTEXT_MENU, {4, 4}, {8, 9}},
+ {ui::kCursorCross, IDR_AURA_CURSOR_BIG_CROSSHAIR, {31, 31}, {31, 31}},
+ {ui::kCursorHelp, IDR_AURA_CURSOR_BIG_HELP, {10, 10}, {8, 9}},
+ {ui::kCursorVerticalText, IDR_AURA_CURSOR_BIG_XTERM_HORIZ,
+ {31, 28}, {31, 28}},
+ {ui::kCursorZoomIn, IDR_AURA_CURSOR_BIG_ZOOM_IN, {26, 26}, {26, 26}},
+ {ui::kCursorZoomOut, IDR_AURA_CURSOR_BIG_ZOOM_OUT, {26, 26}, {26, 26}},
+ {ui::kCursorRowResize, IDR_AURA_CURSOR_BIG_ROW_RESIZE, {28, 31}, {28, 31}},
+ {ui::kCursorColumnResize, IDR_AURA_CURSOR_BIG_COL_RESIZE, {31, 28}, {31, 28}},
+ {ui::kCursorEastWestResize, IDR_AURA_CURSOR_BIG_EAST_WEST_RESIZE,
+ {31, 28}, {31, 28}},
+ {ui::kCursorNorthSouthResize, IDR_AURA_CURSOR_BIG_NORTH_SOUTH_RESIZE,
+ {28, 31}, {28, 31}},
+ {ui::kCursorNorthEastSouthWestResize,
+ IDR_AURA_CURSOR_BIG_NORTH_EAST_SOUTH_WEST_RESIZE, {31, 28}, {31, 28}},
+ {ui::kCursorNorthWestSouthEastResize,
+ IDR_AURA_CURSOR_BIG_NORTH_WEST_SOUTH_EAST_RESIZE, {28, 28}, {28, 28}},
+ {ui::kCursorGrab, IDR_AURA_CURSOR_BIG_GRAB, {20, 13}, {20, 13}},
+ {ui::kCursorGrabbing, IDR_AURA_CURSOR_BIG_GRABBING, {23, 23}, {23, 23}},
+};
+
const CursorData kAnimatedCursors[] = {
{ui::kCursorWait, IDR_THROBBER, {7, 7}, {14, 14}},
{ui::kCursorProgress, IDR_THROBBER, {7, 7}, {14, 14}},
@@ -85,7 +131,12 @@ const CursorSet kCursorSets[] = {
kNormalCursors, arraysize(kNormalCursors),
kAnimatedCursors, arraysize(kAnimatedCursors)
},
- // TODO)yoshiki): Add Large cursor set. crbug.com/247254
+ {
+ CURSOR_SET_LARGE,
+ kLargeCursors, arraysize(kLargeCursors),
+ // TODO(yoshiki): Replace animated cursors with big assets. crbug.com/247254
+ kAnimatedCursors, arraysize(kAnimatedCursors)
+ },
};
const CursorSet* GetCursorSetByType(CursorSetType cursor_set_id) {